@@ -3,7 +3,7 @@ package Thread::Suspend; {
 use strict;
 use warnings;
 
-our $VERSION = '1.19';
+our $VERSION = '1.21';
 
 use threads 1.39;
 use threads::shared 1.01;
@@ -154,7 +154,7 @@ Thread::Suspend - Suspend and resume operations for threads
 
 =head1 VERSION
 
-This document describes Thread::Suspend version 1.19
+This document describes Thread::Suspend version 1.21
 
 =head1 SYNOPSIS
 
@@ -314,12 +314,6 @@ L<Test::More> 0.50 or later (for installation)
 Thread::Suspend Discussion Forum on CPAN:
 L<http://www.cpanforum.com/dist/Thread-Suspend>
 
-Annotated POD for Thread::Suspend:
-L<http://annocpan.org/~JDHEDDEN/Thread-Suspend-1.19/lib/Thread/Suspend.pm>
-
-Source repository:
-L<http://code.google.com/p/thread-suspend/>
-
 L<threads>, L<threads::shared>
 
 =head1 AUTHOR
@@ -328,7 +322,7 @@ Jerry D. Hedden, S<E<lt>jdhedden AT cpan DOT orgE<gt>>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2008 Jerry D. Hedden. All rights reserved.
+Copyright 2006 - 2009 Jerry D. Hedden. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
